==> flutter_prince_of_versions-1.0.0.tar.gz: lib/src/constants.dart <==
part of flutter_prince_of_versions;

class Constants {
  Constants._();

  static const updateAvailable = "update-available";
  static const noUpdate = "no-update";
  static const requiredUpdate = "required-update";

  static const major = "major";
  static const minor = "minor";
  static const patch = "patch";
  static const build = "build";

  static const lastVersionAvailable = "lastVersionAvailable";
  static const installedVersion = "installedVersion";
  static const requiredVersion = "requiredVersion";

  static const status = "status";
  static const version = "version";
  static const updateInfo = "updateInfo";

  static const versionCode = "versionCode";
  static const updatePriority = "updatePriority";
  static const clientVersionStalenessDays = "clientVersionStalenessDays";

  static const canceled = "canceled";
  static const mandatoryUpdateNotAvailable = "mandatory_update_not_available";
  static const downloaded = "downloaded";
  static const downloading = "downloading";
  static const error = "error";
  static const installed = "installed";
  static const installing = "installing";
  static const updateAccepted = "update_accepted";
  static const updateDeclined = "update_declined";
  static const noUpdateCallback = "no_update";
  static const onPending = "on_pending";

  static const channelName = "flutter_prince_of_versions";
  static const requirementsChannelName = "flutter_prince_of_versions_requirements";
  static const checkForUpdatesMethodName = "check_for_updates";
  static const checkUpdatesFromAppStoreMethodName = "check_updates_from_app_store";
  static const checkUpdatesFromPlayStoreMethodName = "check_updates_from_play_store";
}

==> flutter_prince_of_versions-1.0.2.tar.gz: lib/src/constants.dart <==
part of flutter_prince_of_versions;

class Constants {
  Constants._();

  static const updateAvailable = "update-available";
  static const noUpdate = "no-update";
  static const requiredUpdate = "required-update";

  static const major = "major";
  static const minor = "minor";
  static const patch = "patch";
  static const build = "build";

  static const lastVersionAvailable = "lastVersionAvailable";
  static const installedVersion = "installedVersion";
  static const requiredVersion = "requiredVersion";

  static const status = "status";
  static const version = "version";
  static const updateInfo = "updateInfo";

  static const versionCode = "versionCode";
  static const updatePriority = "updatePriority";
  static const clientVersionStalenessDays = "clientVersionStalenessDays";

  static const canceled = "canceled";
  static const mandatoryUpdateNotAvailable = "mandatory_update_not_available";
  static const downloaded = "downloaded";
  static const downloading = "downloading";
  static const error = "error";
  static const installed = "installed";
  static const installing = "installing";
  static const updateAccepted = "update_accepted";
  static const updateDeclined = "update_declined";
  static const noUpdateCallback = "no_update";
  static const onPending = "on_pending";

  static const channelName = "flutter_prince_of_versions";
  static const requirementsChannelName =
      "flutter_prince_of_versions_requirements";
  static const checkForUpdatesMethodName = "check_for_updates";
  static const checkUpdatesFromAppStoreMethodName =
      "check_updates_from_app_store";
  static const checkUpdatesFromPlayStoreMethodName =
      "check_updates_from_play_store";
}
